package cn.wise.sc.cement.business.service.impl;

import cn.hutool.core.bean.BeanUtil;
import cn.hutool.core.util.StrUtil;
import cn.wise.sc.cement.business.entity.*;
import cn.wise.sc.cement.business.mapper.*;
import cn.wise.sc.cement.business.model.*;
import cn.wise.sc.cement.business.model.query.*;
import cn.wise.sc.cement.business.model.vo.*;
import cn.wise.sc.cement.business.service.*;
import cn.wise.sc.cement.business.util.CheckCountUtil;
import cn.wise.sc.cement.business.util.DateUtil;
import cn.wise.sc.cement.business.util.ExcelUtil;
import cn.wise.sc.cement.business.util.RedisUtil;
import com.alibaba.fastjson.JSON;
import com.alibaba.fastjson.JSONArray;
import com.alibaba.fastjson.JSONObject;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.core.toolkit.CollectionUtils;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import io.swagger.models.auth.In;
import lombok.Data;
import org.apache.commons.lang3.StringUtils;
import org.apache.ibatis.annotations.Param;
import org.springframework.beans.BeanUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Propagation;
import org.springframework.transaction.annotation.Transactional;

import javax.annotation.Resource;
import javax.servlet.http.HttpServletResponse;
import java.math.BigDecimal;
import java.text.NumberFormat;
import java.text.ParseException;
import java.text.SimpleDateFormat;
import java.time.LocalDate;
import java.time.LocalDateTime;
import java.util.*;
import java.util.stream.Collectors;

/**
 * <p>
 * 服务实现类
 * </p>
 *
 * @author ztw
 * @since 2021-01-12
 */
@Service
public class DataStatisticsServiceImpl implements IDataStatisticsService {


    @Resource
    private DataStatisticsMapper dataStatisticsMapper;
    @Autowired
    private IProjectService projectService;
    @Autowired
    private IEquipmentService equipmentService;
    @Autowired
    private ISampleService sampleService;
    @Autowired
    private IEntrustService entrustService;
    @Autowired
    private ISampleHandleService sampleHandleService;
    @Autowired
    private ISampleDistributionService sampleDistributionService;
    @Resource
    private TeamMapper teamMapper;
    @Resource
    private SampleMapper sampleMapper;


    /**
     * 统计概览-重要数值统计
     * @return
     */
    @Override
    public BaseResponse<Map<String, String>> countOverview() {
        Map<String, String> map = new HashMap<>();
        //当前进行的项目
        QueryWrapper<Project> projectWrapper = new QueryWrapper<>();
        projectWrapper.eq("status", 1);
        Integer projectCounts = projectService.count(projectWrapper);
        map.put("projectCounts", projectCounts.toString());

        //实验设备总量
        QueryWrapper<Equipment> equipmentWrapper = new QueryWrapper<>();
        Integer equipmentCounts = equipmentService.count(equipmentWrapper);
        map.put("equipmentCounts", equipmentCounts.toString());

        //样品库存总量
        QueryWrapper<Sample> sampleWrapper = new QueryWrapper<>();
        sampleWrapper.ne("status", 2);
        Integer sampleCounts = sampleService.count(sampleWrapper);
        map.put("sampleCounts", sampleCounts.toString());

        //委托单数量
        QueryWrapper<Entrust> entrustWrapper = new QueryWrapper<>();
        Integer entrustCounts = entrustService.count(entrustWrapper);
        map.put("entrustCounts", entrustCounts.toString());

        return BaseResponse.okData(map);
    }

    /**
     * 检测项数量统计-按时间
     * @param cycle
     * @param startDate
     * @param endDate
     * @return
     */
    @Override
    public BaseResponse<List<DataStatisticsVo>> countTeamByTime(Integer cycle, String startDate, String endDate){
        Map<String, Object> params = new HashMap<>();
        params.put("cycle", cycle);
        params.put("startDate", startDate);
        params.put("endDate", endDate);
        List<DataStatisticsVo> list = dataStatisticsMapper.countTeamByTime(params);

        return BaseResponse.okData(list);
    }




    /**
     * 检测项数量统计-按地区
     *
     * @param startDate
     * @param endDate
     * @return
     */
    @Override
    public BaseResponse<List<DataStatisticsVo>> countTeamByOrigin(Integer cycle, String startDate, String endDate) {
        Map<String, Object> params = new HashMap<>();
        params.put("cycle", cycle);
        params.put("startDate", startDate);
        params.put("endDate", endDate);
        List<DataStatisticsVo> list = dataStatisticsMapper.countTeamByOrigin(params);
        return BaseResponse.okData(list);
    }

    /**
     * 委托单进展统计
     * @return
     */
    @Override
    public BaseResponse<Map<String, Object>> countEntrustStatus(Integer cycle, String startDate, String endDate,
                                                                Integer clientId, String clientName){
        Map<String, Object> params = new HashMap<>();
        params.put("cycle", cycle);
        params.put("startDate", startDate);
        params.put("endDate", endDate);
        params.put("clientId", clientId);
        params.put("clientName", clientName);
        Map<String, Object> map = new HashMap<>();
        Integer sum_counts = dataStatisticsMapper.countEntrustSumNum(params);
        if(sum_counts == null){
            map.put("sumCounts", "0");
            map.put("statusList", null);
            map.put("typeList", null);
        }else{
            List<DataStatisticsVo> statusList = dataStatisticsMapper.countEntrustStatus(params);
            List<DataStatisticsVo> typeList = dataStatisticsMapper.countEntrustType(params);
            map.put("sumCounts", sum_counts);
            map.put("statusList", statusList);
            map.put("typeList", typeList);
        }
        return BaseResponse.okData(map);
    }



    /**
     * 委托单进展统计-列表
     * @param pageQuery
     * @return
     */
    @Override
    public BaseResponse<IPage<EntrustVo>> countEntrustPage(PageQuery pageQuery, Integer cycle, String startDate,
                                                           String endDate, Integer clientId, String clientName){
        Map<String, Object> params = new HashMap<>();
        params.put("cycle", cycle);
        params.put("startDate", startDate);
        params.put("endDate", endDate);
        params.put("clientId", clientId);
        params.put("clientName", clientName);
        Page<EntrustVo> page = new Page<>(pageQuery.getPageNo(), pageQuery.getPageSize());
        IPage<EntrustVo> pages = dataStatisticsMapper.countEntrustPage(page, params);
        List<EntrustVo> list = pages.getRecords();

        if (list != null && list.size() > 0) {
            for (EntrustVo entrustVo : list) {
                //只统计主样的信息
                List<Sample> sampleList = sampleMapper.getSampleList(entrustVo.getId());
                //检测项目名称
                List<Integer> teamIdList = new ArrayList<>();
                Map<String, Integer> teamMap = new HashMap<>();
                //所有样品主样的产值
                BigDecimal outputValue = new BigDecimal("0.00");
                if (sampleList != null && sampleList.size() > 0) {
                    //样品名称 列表中的拼接
                    for (Sample sample : sampleList) {
                        if(sample.getOutputValue() != null){
                            outputValue = outputValue.compareTo(BigDecimal.ZERO) == 0 ?
                                    sample.getOutputValue() : (outputValue.add(sample.getOutputValue()));
                        }
                        String teamIds = sample.getTeamIds();
                        String checkTeam = "";
                        if (teamIds != null) {
                            String[] teamIdS = teamIds.split("、");
                            for (String teamId : teamIdS) {
                                Team team = teamMapper.selectById(Integer.valueOf(teamId));
                                if (team != null) {
                                    if(!teamIdList.contains(team.getId())){
                                        teamMap.put(team.getName(), 1);
                                        teamIdList.add(team.getId());
                                    }else{
                                        teamMap.put(team.getName(), teamMap.get(team.getName())+1);
                                    }
                                    checkTeam = checkTeam.equals("") ? team.getName() : (checkTeam + "、" + team.getName());
                                }
                            }
                        }

                    }
                }
                JSONArray checkElementArray = mapToJSONArray(teamMap);
                String teamString = JSON.toJSON(checkElementArray).toString();
                entrustVo.setCheckTeam(teamString);
                entrustVo.setOutputValue(outputValue);
            }
        }

        return BaseResponse.okData(pages);
    }

    //Map转json数组
    public JSONArray mapToJSONArray( Map<String, Integer> map){
        JSONArray jsonArray = new JSONArray();
        for(Map.Entry<String,Integer> entry : map.entrySet()){
            JSONObject jsonObject = new JSONObject();
            jsonObject.put("name",entry.getKey());
            jsonObject.put("value",entry.getValue());
            jsonArray.add(jsonObject);
        }
        return jsonArray;
    }

    /**
     * 委托单进展统计-列表导出
     * @param cycle
     * @param startDate
     * @param endDate
     * @param clientId
     * @param clientName
     * @param fileName
     * @param response
     */
    @Override
    public void exportEntrustList(Integer cycle, String startDate,
                                                           String endDate, Integer clientId, String clientName, String fileName, HttpServletResponse response){
        Map<String, Object> params = new HashMap<>();
        params.put("cycle", cycle);
        params.put("startDate", startDate);
        params.put("endDate", endDate);
        params.put("clientId", clientId);
        params.put("clientName", clientName);
        List<Map<String, Object>> list = dataStatisticsMapper.exportEntrustList(params);

        if (!CollectionUtils.isEmpty(list)) {
            String[] headers = new String[12];
            headers[0] = "序号";
            headers[1] = "委托单号";
            headers[2] = "项目名称";
            headers[3] = "项目编号";
            headers[4] = "项目类型";
            headers[5] = "委托人";
            headers[6] = "委托单位";
            headers[7] = "委托日期";
            headers[8] = "样品数量";
            headers[9] = "检测项目";
            headers[10] = "产值";
            headers[11] = "状态";
            List<Object[]> datas = new ArrayList<>(list.size());
            for (Map<String, Object> m : list) {
                Object[] objects = new Object[headers.length];

                String objj = m.get("entrustId").toString();
                Integer entrustId = Integer.valueOf(objj);
                //只统计主样的信息
                List<Sample> sampleList = sampleMapper.getSampleList(entrustId);
                //检测项目名称
                List<Integer> teamIdList = new ArrayList<>();
                Map<String, Integer> teamMap = new HashMap<>();
                //所有样品主样的产值
                BigDecimal outputValue = new BigDecimal("0.00");
                if (sampleList != null && sampleList.size() > 0) {
                    //样品名称 列表中的拼接
                    for (Sample sample : sampleList) {
                        if(sample.getOutputValue() != null){
                            outputValue = outputValue.compareTo(BigDecimal.ZERO) == 0 ?
                                    sample.getOutputValue() : (outputValue.add(sample.getOutputValue()));
                        }
                        String teamIds = sample.getTeamIds();
                        String checkTeam = "";
                        if (teamIds != null) {
                            String[] teamIdS = teamIds.split("、");
                            for (String teamId : teamIdS) {
                                Team team = teamMapper.selectById(Integer.valueOf(teamId));
                                if (team != null) {
                                    if(!teamIdList.contains(team.getId())){
                                        teamMap.put(team.getName(), 1);
                                        teamIdList.add(team.getId());
                                    }else{
                                        teamMap.put(team.getName(), teamMap.get(team.getName())+1);
                                    }
                                    checkTeam = checkTeam.equals("") ? team.getName() : (checkTeam + "、" + team.getName());
                                }
                            }
                        }

                    }
                }
//                JSONArray checkElementArray = mapToJSONArray(teamMap);
//                String teamString = JSON.toJSON(checkElementArray).toString();

                for (int j = 0; j < headers.length; j++) {
                    String obj = "";
                    if(j == 9){
                        objects[9] = teamMap;
                    }else if(j == 10){
                        objects[10] = outputValue;
                    }else{
                        obj = m.get(headers[j]).toString();
                        if (j == 0) {
                            obj = obj.split("\\.")[0];
                        }
                        objects[j] = obj;
                    }
                }
                datas.add(objects);
            }
            ExcelUtil.excelExport(
                    fileName == null || fileName.trim().length() <= 0 ? "委托单进展统计-列表导出" : fileName, headers,
                    datas, response);
        }


    }



    /**
     * 进行中任务数量统计
     * @return
     */
    @Override
    public BaseResponse<Map<String, Object>> countTaskIng(PageQuery pageQuery, String startDate, String endDate){
        Map<String, Object> map = new HashMap<>();
        //样品处理任务数量
        QueryWrapper<SampleHandle> handleQw = new QueryWrapper<>();
        handleQw.ge("create_time",startDate);
        handleQw.le("create_time",endDate);
        handleQw.eq("status",0).or().eq("status",1);
        Integer handle_counts = sampleHandleService.count(handleQw);
        map.put("handleCounts", handle_counts);

        //样品检测任务数量
        QueryWrapper<SampleDistribution> distributionQw = new QueryWrapper<>();
        distributionQw.ge("create_time",startDate);
        distributionQw.le("create_time",endDate);
        distributionQw.eq("status",0).or().eq("status",1);
        Integer distribution_counts = sampleDistributionService.count(distributionQw);
        map.put("distributionCounts", distribution_counts);


        //样品处理按人分组统计任务数量
        Map<String, Object> paramsHan = new HashMap<>();
        paramsHan.put("startDate", startDate);
        paramsHan.put("endDate", endDate);
        Page<EntrustVo> pageHan = new Page<>(pageQuery.getPageNo(), pageQuery.getPageSize());
        IPage<DataStatisticsVo> pagesHandle = dataStatisticsMapper.countHandlePage(pageHan, paramsHan);
        List<DataStatisticsVo> listHandle = pagesHandle.getRecords();
        List<DataStatisticsVo> handleList = new ArrayList<>();
        if (listHandle != null && listHandle.size() > 0) {
            for (DataStatisticsVo dataStatisticsVo : listHandle) {
                //weekType 1上周数据 2本周数据
                Integer upWeekNums =  dataStatisticsMapper.countHandleWeek(dataStatisticsVo.getId(), 1);
                upWeekNums = upWeekNums==null ? 0 : upWeekNums;
                Integer thisweekNums =  dataStatisticsMapper.countHandleWeek(dataStatisticsVo.getId(), 2);
                thisweekNums = thisweekNums==null ? 0 : thisweekNums;

                // 创建一个数值格式化对象  ↑↓
                NumberFormat numberFormat = NumberFormat.getInstance();
                // 设置精确到小数点后2位
                numberFormat.setMaximumFractionDigits(2);
                String resultNum = "";
                if(thisweekNums > upWeekNums){
                    if(upWeekNums ==0){
                        resultNum = "100%↑";
                    }else{
                        Integer errorNums = thisweekNums - upWeekNums;
                        resultNum = numberFormat.format((float)errorNums/(float)thisweekNums*100) + "%↑";
                    }

                }else if(upWeekNums > thisweekNums){
                    if(thisweekNums ==0){
                        resultNum = "100%↓";
                    }else{
                        Integer errorNums = upWeekNums - thisweekNums ;
                        resultNum = numberFormat.format((float)errorNums/(float)upWeekNums*100) + "%↓";
                    }

                }else if(thisweekNums == thisweekNums){
                    resultNum = "0%";
                }
                dataStatisticsVo.setWeekUp(resultNum);

                handleList.add(dataStatisticsVo);
            }
        }
        pagesHandle.setRecords(handleList);
        map.put("pagesHandle", pagesHandle);


        //样品检测按人分组统计任务数量
        Map<String, Object> paramsDis = new HashMap<>();
        paramsDis.put("startDate", startDate);
        paramsDis.put("endDate", endDate);
        Page<EntrustVo> pageDis = new Page<>(pageQuery.getPageNo(), pageQuery.getPageSize());
        IPage<DataStatisticsVo> pagesDistribution = dataStatisticsMapper.countDistributionPage(pageDis, paramsDis);
        List<DataStatisticsVo> listDistribution = pagesDistribution.getRecords();
        List<DataStatisticsVo> distributionList = new ArrayList<>();
        if (listDistribution != null && listDistribution.size() > 0) {
            for (DataStatisticsVo dataStatisticsVo : listDistribution) {
                //weekType 1上周数据 2本周数据
                Integer upWeekNums =  dataStatisticsMapper.countDistributionWeek(dataStatisticsVo.getId(), 1);
                upWeekNums = upWeekNums==null ? 0 : upWeekNums;
                Integer thisweekNums =  dataStatisticsMapper.countDistributionWeek(dataStatisticsVo.getId(), 2);
                thisweekNums = thisweekNums==null ? 0 : thisweekNums;

                // 创建一个数值格式化对象  ↑↓
                NumberFormat numberFormat = NumberFormat.getInstance();
                // 设置精确到小数点后2位
                numberFormat.setMaximumFractionDigits(2);
                String resultNum = "";
                if(thisweekNums > upWeekNums){
                    if(upWeekNums ==0){
                        resultNum = "100%↑";
                    }else{
                        Integer errorNums = thisweekNums - upWeekNums;
                        resultNum = numberFormat.format((float)errorNums/(float)thisweekNums*100) + "%↑";
                    }

                }else if(upWeekNums > thisweekNums){
                    if(thisweekNums ==0){
                        resultNum = "100%↓";
                    }else{
                        Integer errorNums = upWeekNums - thisweekNums ;
                        resultNum = numberFormat.format((float)errorNums/(float)upWeekNums*100) + "%↓";
                    }

                }else if(thisweekNums == thisweekNums){
                    resultNum = "0%";
                }
                dataStatisticsVo.setWeekUp(resultNum);

                distributionList.add(dataStatisticsVo);
            }
        }
        pagesDistribution.setRecords(distributionList);

        map.put("pagesDistribution", pagesDistribution);

        return BaseResponse.okData(map);
    }

    /**
     * 正在进行的检测项统计
     * @return
     */
    @Override
    public BaseResponse<List<DataStatisticsVo>> countTeamIng(String startDate, String endDate){
        Map<String, Object> params = new HashMap<>();
        params.put("startDate", startDate);
        params.put("endDate", endDate);
        List<DataStatisticsVo> list = dataStatisticsMapper.countTeamIng(params);
        return BaseResponse.okData(list);
    }

    /**
     * 检测项数量统计
     * @return
     */
    @Override
    public BaseResponse<List<DataStatisticsVo>> countTeamDetail(Integer cycle, String startDate, String endDate){
        Map<String, Object> params = new HashMap<>();
        params.put("cycle", cycle);
        params.put("startDate", startDate);
        params.put("endDate", endDate);
        List<DataStatisticsVo> list = dataStatisticsMapper.countTeam(params);
        return BaseResponse.okData(list);
    }

    /**
     * 检测项目数量统计-列表
     * @return
     */
    @Override
    public BaseResponse<IPage<DataStatisticsTeamVo>> countTeamList(PageQuery pageQuery, Integer cycle, String startDate, String endDate){
        Map<String, Object> params = new HashMap<>();
        params.put("cycle", cycle);
        params.put("startDate", startDate);
        params.put("endDate", endDate);
        Page<DataStatisticsTeamVo> page = new Page<>(pageQuery.getPageNo(), pageQuery.getPageSize());
        IPage<DataStatisticsTeamVo> pages = dataStatisticsMapper.countTeamPage(page, params);
        List<DataStatisticsTeamVo> list = pages.getRecords();
        if (list != null && list.size() > 0) {
            for (DataStatisticsTeamVo dstVo : list) {
                Integer entrustNum = dataStatisticsMapper.countEntrustNum(dstVo.getId());
                dstVo.setEntrustNum(entrustNum);
                Integer sampleNum = dataStatisticsMapper.countSampleNum(dstVo.getId());
                dstVo.setSampleNum(sampleNum);
            }
        }

        return BaseResponse.okData(pages);
    }

    /**
     * 检测项统计-列表导出
     * @param cycle
     * @param startDate
     * @param endDate
     * @param fileName
     * @param response
     */
    @Override
    public void exportTeamList(Integer cycle, String startDate, String endDate, String fileName, HttpServletResponse response){
        Map<String, Object> params = new HashMap<>();
        params.put("cycle", cycle);
        params.put("startDate", startDate);
        params.put("endDate", endDate);
        List<Map<String, Object>> list = dataStatisticsMapper.exportTeamList(params);

        if (!CollectionUtils.isEmpty(list)) {
            String[] headers = new String[5];
            headers[0] = "序号";
            headers[1] = "检测项目";
            headers[2] = "检测项数量";
            headers[3] = "委托数量";
            headers[4] = "样品数量";

            List<Object[]> datas = new ArrayList<>(list.size());
            for (Map<String, Object> m : list) {
                Object[] objects = new Object[headers.length];

                for (int j = 0; j < headers.length; j++) {
                    String obj = "";
                    if(j == 3){
                        obj = m.get("id").toString();
                        Integer teamId = Integer.valueOf(obj);
                        Integer entrustNum = dataStatisticsMapper.countEntrustNum(teamId);
                        objects[3] = entrustNum;

                    }else if(j == 4){
                        obj = m.get("id").toString();
                        Integer teamId = Integer.valueOf(obj);
                        Integer sampleNum = dataStatisticsMapper.countSampleNum(teamId);
                        objects[4] = sampleNum;
                    }else{
                        obj = m.get(headers[j]).toString();
                        if (j == 0) {
                            obj = obj.split("\\.")[0];
                        }
                        objects[j] = obj;
                    }
                }
                datas.add(objects);
            }
            ExcelUtil.excelExport(
                    fileName == null || fileName.trim().length() <= 0 ? "检测项统计-列表导出" : fileName, headers,
                    datas, response);
        }

    }







    /**
     * 各委托单位项目数量统计
     * @return
     */
    @Override
    public BaseResponse<List<DataStatisticsVo>> countByClient(){
        List<DataStatisticsVo>  list = dataStatisticsMapper.countByClient();
        return BaseResponse.okData(list);
    }

    /**
     * 检测元素含量分布情况统计
     * @param query    请求参数
     * @param response 响应
     * @return
     */
    @Override
    public BaseResponse<Page<ItemDistributionVo>> countItemDistribution(CountItemDistributionQuery query, HttpServletResponse response) {

        String startTime = query.getStartTime();
        String endTime = query.getEndTime();
        Long itemId = query.getItemId();
        List<String> origins = query.getOrigins();

        Page<ItemDistribution> page = new Page<>(query.getPageQuery().getPageNo(), query.getPageQuery().getPageSize());

        //获取检测项目城市分布统计
        IPage<ItemDistribution> list = dataStatisticsMapper
                .countItemDistribution(page, startTime, endTime, origins, itemId);

        List<ItemDistribution> records = list.getRecords();
        List<ItemDistributionVo> rtsRecords = new ArrayList<>(records.size());

        //组装检查项统计和按照样品统计
        for (ItemDistribution distribution : records) {
            String key = distribution.getKey();
            String[] split = key.split(",");
            String teamId = split[0];
            String origin = split[1];
            //检测项按样品分布统计
            ItemDistributionSample sample = dataStatisticsMapper
                    .countItemDistributionSample(startTime, endTime, origin, Long.parseLong(teamId));
            ItemDistributionVo vo = new ItemDistributionVo();
            vo.setOrigin(origin);
            vo.setItemName(sample.getName());
            vo.setSampleCount(sample.getCount());
            vo.setItemCount(distribution.getCount());
            if(StringUtils.isEmpty(startTime) || StringUtils.isEmpty(endTime)){
                vo.setTime(null);
            }else{
                vo.setTime(startTime + "_" + endTime);
            }
            rtsRecords.add(vo);
        }

        Page<ItemDistributionVo> rts = new Page<>();
        rts.setRecords(rtsRecords);
        rts.setCurrent(page.getCurrent());
        rts.setPages(page.getPages());
        rts.setTotal(page.getTotal());
        rts.setSize(page.getSize());

        return BaseResponse.okData(rts);
    }





    /**
     * 元素含量分布统计-列表导出
     * @param query
     * @param fileName
     * @param response
     */
    @Override
    public void exportItemDistribution(CountItemDistributionQuery query, String fileName, HttpServletResponse response){
        String startTime = query.getStartTime();
        String endTime = query.getEndTime();
        Long itemId = query.getItemId();
        List<String> origins = query.getOrigins();
        List<Map<String, Object>> list = dataStatisticsMapper.exporItemDistributionList(startTime, endTime, origins, itemId);

        if (!CollectionUtils.isEmpty(list)) {
            String[] headers = new String[5];
            headers[0] = "序号";
            headers[1] = "检测元素";
            headers[2] = "地区";
            headers[3] = "元素含量";
            headers[4] = "样品数量";

            List<Object[]> datas = new ArrayList<>(list.size());
            for (Map<String, Object> m : list) {
                Object[] objects = new Object[headers.length];


                String objj = m.get("key").toString();
                String[] split = objj.split(",");
                String teamId = split[0];
                String origin = split[1];
                //检测项按样品分布统计
                ItemDistributionSample sample = dataStatisticsMapper
                        .countItemDistributionSample(startTime, endTime, origin, Long.parseLong(teamId));

                ItemDistributionVo vo = new ItemDistributionVo();
                vo.setOrigin(origin);
                vo.setItemName(sample.getName());
                vo.setSampleCount(sample.getCount());
                vo.setItemCount(Integer.valueOf(m.get("count").toString()));
                if(StringUtils.isEmpty(startTime) || StringUtils.isEmpty(endTime)){
                    vo.setTime(null);
                }else{
                    vo.setTime(startTime + "_" + endTime);
                }
                for (int j = 0; j < headers.length; j++) {
                    String obj = "";
                    if(j == 1){
                        objects[1] = vo.getItemName();
                    }else if(j == 2){
                        objects[2] = vo.getOrigin();
                    }else if(j == 3){
                        objects[3] = vo.getItemCount();
                    }else if(j == 4){
                        objects[4] = vo.getSampleCount();
                    }else{
                        obj = m.get(headers[j]).toString();
                        if (j == 0) {
                            obj = obj.split("\\.")[0];
                        }
                        objects[j] = obj;
                    }

                }
                datas.add(objects);
            }
            ExcelUtil.excelExport(
                    fileName == null || fileName.trim().length() <= 0 ? "元素含量分布统计-列表导出" : fileName, headers,
                    datas, response);
        }

    }




















}
